"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.SyntaxHighlighter = void 0;
var _react = _interopRequireWildcard(require("react"));
var _reactNative = require("react-native");
var _SyntaxContext = require("./SyntaxContext");
var _jsxRuntime = require("react/jsx-runtime");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function (e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
/* eslint-disable no-console */

const DEBUG = true;
function log(...args) {
  if (DEBUG) console.log('[SyntaxHighlighter]', ...args);
}
const styles = _reactNative.StyleSheet.create({
  container: {
    flex: 1
  },
  line: {
    flexDirection: 'row',
    flexWrap: 'wrap'
  }
});
const SyntaxHighlighter = exports.SyntaxHighlighter = /*#__PURE__*/(0, _react.memo)(({
  code,
  language,
  theme = 'github-dark',
  fontSize = 14
}) => {
  const {
    highlighter,
    isReady
  } = (0, _SyntaxContext.useShiki)();
  const [tokens, setTokens] = (0, _react.useState)([]);
  const [error, setError] = (0, _react.useState)(null);
  const highlight = (0, _react.useCallback)(async () => {
    if (!highlighter || !isReady) return;
    try {
      const loadedLangs = highlighter.getLoadedLanguages();
      const normalizedLang = language.toLowerCase();
      const effectiveLang = loadedLangs.includes(normalizedLang) ? normalizedLang : 'text';
      log('Starting tokenization:', {
        lang: effectiveLang,
        theme: typeof theme === 'string' ? theme : theme.name,
        snippet: code.slice(0, 50)
      });

      // Get grammar info
      const grammar = highlighter.getLanguage(effectiveLang);
      log('Using grammar:', {
        name: grammar.name,
        // Only log properties we know exist on Grammar
        id: typeof grammar === 'object' && 'id' in grammar ? grammar.id : undefined
      });

      // Handle theme data
      const themeName = typeof theme === 'string' ? theme : theme.name;
      const themeData = highlighter.getTheme(themeName || 'default');
      log('Using theme:', {
        name: themeData.name,
        type: themeData.type,
        settingsCount: themeData.settings?.length ?? 0
      });

      // Use explicit tokenization settings
      const results = highlighter.codeToTokensBase(code, {
        lang: effectiveLang,
        theme: themeName,
        includeExplanation: true
      });
      if (results[0]?.length === 1) {
        log('WARNING: Single token per line:', {
          total: results.length,
          firstLine: results[0]
        });
      }
      log('Tokenization results:', {
        lines: results.length,
        tokenCounts: results.map(line => line.length),
        firstLineTokens: results[0]?.map(token => ({
          content: token.content,
          color: token.color,
          scopes: token.explanation?.[0]?.scopes
        }))
      });
      setTokens(results);
      setError(null);
    } catch (err) {
      const msg = err instanceof Error ? err.message : 'Failed to highlight code';
      console.error('Highlighting error:', err);
      setError(msg);
    }
  }, [code, language, theme, highlighter, isReady]);
  (0, _react.useEffect)(() => {
    highlight();
  }, [highlight]);

  // Log render cycles
  (0, _react.useEffect)(() => {
    if (tokens.length) {
      log('Rendering tokens:', {
        lineCount: tokens.length,
        tokensPerLine: tokens.map(line => line.length),
        sample: tokens[0]?.slice(0, 2)
      });
    }
  }, [tokens]);
  if (!isReady) {
    return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      style: styles.container,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: {
          fontSize
        },
        children: code
      })
    });
  }
  if (error) {
    return /*#__PURE__*/(0, _jsxRuntime.jsxs)(_reactNative.View, {
      style: styles.container,
      children: [/*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: {
          color: 'red'
        },
        children: error
      }), /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
        style: {
          fontSize
        },
        children: code
      })]
    });
  }
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.ScrollView, {
    horizontal: true,
    style: styles.container,
    contentContainerStyle: {
      padding: 10
    },
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
      children: tokens.map((line, i) => /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: styles.line,
        children: line.map((token, j) => {
          if (i === 0 && j < 3) {
            log('Rendering token:', {
              content: token.content,
              color: token.color,
              scopes: token.explanation?.[0]?.scopes
            });
          }
          return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
            style: {
              color: token.color || '#e1e4e8',
              fontSize,
              ...(token.fontStyle && token.fontStyle & 1 && {
                fontStyle: 'italic'
              }),
              ...(token.fontStyle && token.fontStyle & 2 && {
                fontWeight: 'bold'
              })
            },
            children: token.content
          }, `${i}-${j}`);
        })
      }, i))
    })
  });
});
//# sourceMappingURL=SyntaxHighlighter.js.map